@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 #
 # Georges Toth (c) 2016-present <georges@trypill.org>
@@ -20,6 +19,8 @@
 
 
 import datetime
+import json
+
 import openhab
 
 base_url = 'http://localhost:8080/rest'
@@ -41,3 +42,19 @@ else:
   knx_day_night.off()
 
 print(knx_day_night.state)
+
+# start_time for fetching persistence data
+start_time = datetime.datetime.fromtimestamp(1695504300123 / 1000, tz=datetime.UTC)
+
+# fetch persistence data using the OpenHAB client object
+for k in openhab.get_item_persistence(knx_day_night.name,
+                                      page_length=20,
+                                      start_time=start_time
+                                      ):
+  print(json.dumps(k, indent=4))
+
+# fetch persistence data using the item directly
+for k in knx_day_night.persistence(page_length=20,
+                                   start_time=start_time
+                                   ):
+  print(json.dumps(k, indent=4))
